@@ -27,6 +27,9 @@ class DummyClass:
         return a + b
 
 
+dummy_instance = DummyClass()
+
+
 @pytest.fixture
 def memjobstore():
     yield MemoryJobStore()
@@ -112,19 +115,33 @@ def create_add_job(timezone, create_job):
     return create
 
 
-def test_add_instance_method_job(jobstore, create_add_job):
+def test_add_callable_instance_method_job(jobstore, create_add_job):
     instance = DummyClass()
     initial_job = create_add_job(jobstore, instance.dummy_method, kwargs={'a': 1, 'b': 2})
     job = jobstore.lookup_job(initial_job.id)
     assert job.func(*job.args, **job.kwargs) == 3
 
 
-def test_add_class_method_job(jobstore, create_add_job):
+def test_add_callable_class_method_job(jobstore, create_add_job):
     initial_job = create_add_job(jobstore, DummyClass.dummy_classmethod, kwargs={'a': 1, 'b': 2})
     job = jobstore.lookup_job(initial_job.id)
     assert job.func(*job.args, **job.kwargs) == 3
 
 
+def test_add_textual_instance_method_job(jobstore, create_add_job):
+    initial_job = create_add_job(jobstore, 'tests.test_jobstores:dummy_instance.dummy_method',
+                                 kwargs={'a': 1, 'b': 2})
+    job = jobstore.lookup_job(initial_job.id)
+    assert job.func(*job.args, **job.kwargs) == 3
+
+
+def test_add_textual_class_method_job(jobstore, create_add_job):
+    initial_job = create_add_job(jobstore, 'tests.test_jobstores:DummyClass.dummy_classmethod',
+                                 kwargs={'a': 1, 'b': 2})
+    job = jobstore.lookup_job(initial_job.id)
+    assert job.func(*job.args, **job.kwargs) == 3
+
+
 def test_lookup_job(jobstore, create_add_job):
     initial_job = create_add_job(jobstore)
     job = jobstore.lookup_job(initial_job.id)
